@@ -502,9 +502,13 @@ class Story(Configurable):
 
     def setMetadata(self, key, value, condremoveentities=True):
 
-        # delete
+        # delete cached replace'd value.
         if key in self.processed_metadata_cache:
             del self.processed_metadata_cache[key]
+        # Fixing everything downstream to handle bool primatives is a
+        # pain.
+        if isinstance(value,bool):
+            value = unicode(value)
         # keep as list type, but set as only value.
         if self.isList(key):
             self.addToList(key,value,condremoveentities=condremoveentities,clear=True)
@@ -587,7 +591,9 @@ class Story(Configurable):
         retlist = [value]
         for replaceline in self.replacements:
             (repl_line,metakeys,regexp,replacement,cond_match) = replaceline
-            #print("replacement tuple:%s"%replaceline)
+            # logger.debug("replacement tuple:%s"%replaceline)
+            # logger.debug("key:%s value:%s"%(key,value))
+            # logger.debug("value class:%s"%value.__class__.__name__)
             if (metakeys == None or key in metakeys) \
                     and isinstance(value,basestring) \
                     and regexp.search(value):
@@ -649,6 +655,7 @@ class Story(Configurable):
     def dump_html_metadata(self):
         lines=[]
         for k,v in sorted(six.iteritems(self.metadata)):
+            #logger.debug("k:%s v:%s"%(k,v))
             classes=['metadata']
             if isinstance(v, (datetime.date, datetime.datetime, datetime.time)):
                 classes.append("datetime")
@@ -698,12 +705,17 @@ class Story(Configurable):
                 for i in tag.find_all('li'):
                     val.append(i.string)
             elif 'int' in tag['class']:
-                val = int(tag.string)
+                # Python reports true when asked isinstance(<bool>, (int))
+                # bools now converted to unicode when set.
+                if tag.string in ('True','False'):
+                    val = tag.string
+                else:
+                    val = int(tag.string)
             else:
                 val = unicode("\n".join([ unicode(c) for c in tag.contents ]))
 
             #logger.debug("key(%s)=val(%s)"%(tag['id'],val))
-            if val:
+            if val != None:
                 self.metadata[tag['id']]=val
 
         # self.metadata = json.loads(s, object_hook=datetime_decoder)
